@@ -112,6 +112,16 @@ class Assembler {
 					return 1;
 				}
 				break;
+
+			case "--addins":
+				if (i < argc){
+					Provider populator = new AddinsProvider (args [++i]);
+					list.Add (populator);
+				} else {
+					Usage ();
+					return 1;
+				}
+				break;
 			
 			default:
 				Usage ();
