@@ -33,7 +33,7 @@ using BF = System.Reflection.BindingFlags;
 //
 // Helper routines to extract information from an Ecma XML document
 //
-public class EcmaDoc {
+public static class EcmaDoc {
 	public static string GetFullClassName (XmlDocument doc)
 	{
 		return doc.SelectSingleNode ("/Type").Attributes ["FullName"].InnerText;
@@ -130,6 +130,14 @@ public class EcmaDoc {
 		
 		return type;
 	}
+
+	internal static string GetNamespaceFile (string dir, string ns)
+	{
+		string nsxml = Path.Combine (dir, "ns-" + ns + ".xml");
+		if (!File.Exists (nsxml))
+			nsxml = Path.Combine (dir, ns + ".xml");
+		return nsxml;
+	}
 }
 
 //
@@ -169,7 +177,7 @@ public class EcmaProvider : Provider {
 					tn = Path.GetFileName (ns);
 					Console.Error.WriteLine ("Processing namespace {0}", tn);
 					ns_node = tree.LookupNode (tn, "N:" + tn);
-					string ns_summary_file = basedir + "/" + tn + ".xml";
+					string ns_summary_file = EcmaDoc.GetNamespaceFile (basedir, tn);
 					
 					nsnodes[ns_node] = nsnodes;
 					
@@ -1938,7 +1946,7 @@ public class EcmaUncompiledHelpSource : EcmaHelpSource {
 	
 	protected override XmlReader GetNamespaceDocument (string ns) {
 		XmlDocument nsdoc = new XmlDocument();
-		nsdoc.Load(Path.Combine(basedir.FullName, ns + ".xml"));
+		nsdoc.Load (EcmaDoc.GetNamespaceFile (basedir.FullName, ns));
 		
 		XmlDocument elements = new XmlDocument();
 		XmlElement docnode = elements.CreateElement("elements");
