@@ -15,6 +15,7 @@ namespace Monodoc {
 using System;
 using System.IO;
 using System.Text;
+using System.Text.RegularExpressions;
 using System.Collections;
 using System.Configuration;
 using System.Xml;
@@ -799,82 +800,8 @@ public class RootTree : Tree {
 				}
 				string path = a.InnerText;
 
-				HelpSource hs = null;
 				string basefilepath = Path.Combine (sources_dir, basefile);
-				switch (provider){
-				case "ecma":
-					try {
-						hs = new EcmaHelpSource (basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-				case "ecma-uncompiled":
-					try {
-						hs = new EcmaUncompiledHelpSource (basefilepath);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-				case "monohb":
-					try {
-						hs = new MonoHBHelpSource(basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-				case "xhtml":
-					try {
-						hs = new XhtmlHelpSource (basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-
-				case "man":
-					try {
-						hs = new ManHelpSource (basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-				
-				case "simple":
-					try {
-						hs = new SimpleHelpSource (basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-					
-				case "error":
-					try {
-						hs = new ErrorHelpSource (basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-					
-				case "ecmaspec":
-					try {
-						hs = new EcmaSpecHelpSource (basefilepath, false);
-					} catch (FileNotFoundException) {
-						Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
-						break;
-					}
-					break;
-				default:
-					Console.Error.WriteLine ("Error: Unknown provider specified: {0}", provider);
-					break;
-				}
-				
+				HelpSource hs = GetHelpSource (provider, basefilepath);
 				if (hs == null)
 					continue;
 				root.help_sources.Add (hs);
@@ -906,6 +833,41 @@ public class RootTree : Tree {
 
 		return root;
 	}
+	
+	static HelpSource GetHelpSource (string provider, string basefilepath)
+	{
+		try {
+			switch (provider){
+			case "ecma":
+				return new EcmaHelpSource (basefilepath, false);
+			case "ecma-uncompiled":
+				return new EcmaUncompiledHelpSource (basefilepath);
+			case "monohb":
+				return new MonoHBHelpSource(basefilepath, false);
+			case "xhtml":
+				return new XhtmlHelpSource (basefilepath, false);
+			case "man":
+				return new ManHelpSource (basefilepath, false);
+			case "simple":
+				return new SimpleHelpSource (basefilepath, false);
+			case "error":
+				return new ErrorHelpSource (basefilepath, false);
+			case "ecmaspec":
+				return new EcmaSpecHelpSource (basefilepath, false);
+			case "addins":
+				return new AddinsHelpSource (basefilepath, false);
+			default:
+				Console.Error.WriteLine ("Error: Unknown provider specified: {0}", provider);
+				break;
+			}
+			return null;
+		}
+		catch (FileNotFoundException) {
+			Console.Error.WriteLine ("Error: did not find one of the files in sources/"+basefilepath);
+			return null;
+		}
+	}
+		
 
 	//
 	// Maintains the name to node mapping
@@ -1018,7 +980,7 @@ public class RootTree : Tree {
 	
 	public string TypeLookup (string url, out Node match_node)
 	{
-		string rest = url.Substring (2);
+		string rest = Regex.Replace (url, @"^T:\s*", "");
 		string ns, type;
 
 		if (!GetNamespaceAndType (rest, out ns, out type)){
@@ -1040,7 +1002,7 @@ public class RootTree : Tree {
 
 	public string MemberLookup (string prefix, string url, out Node match_node)
 	{
-		string rest = url.Substring (2);
+		string rest = Regex.Replace (url, @"^.:\s*", "");
 		
 		// Dots in the arg list (for methods) confuse this.
 		// Chop off the arg list for now and put it back later.
